@@ -1,7 +1,7 @@
 
 from milkycow import *
-from codelib.base import base64encode as benc
-from codelib.base import base64decode as bdec
+from codelib.rot import  rot47IterForword as benc
+from codelib.rot import rot47IterBackword as bdec
 from re import search, ASCII
 from getpass import getpass as ainput
 from os import remove, stat
@@ -25,7 +25,7 @@ RDATA = {
 
 
 class Fundb:
-    def __init__(self, db_name, password = "pass", rotate = 420):
+    def __init__(self, db_name, password = "pass", rotate = 222):
         if(db_name in RDATA["EXP"]):
             raise Exception(RDATA["INE"])
         self.db_name = db_name
@@ -44,7 +44,7 @@ class Fundb:
         if(type(data) != dict):
             raise Exception(RDATA["TYE2"])
         with open(self.db_name+self.exten, "w") as a:
-            enc_data = encrypt(benc(str(data)), self.passwd, self.rotate, self.layer, self.rrotate)
+            enc_data = encrypt(str(data), self.passwd, self.rotate)
             a.write(enc_data)
             a.close()
             if(verbose):
@@ -59,9 +59,9 @@ class Fundb:
         """
         try:
             with open(self.db_name+self.exten, "r") as a:
-                data = decrypt(a.read(), self.passwd, self.rotate, self.layer, self.rrotate)
+                data = decrypt(a.read(), self.passwd, self.rotate)
                 a.close()
-                return eval(bdec(data))
+                return eval(data)
         except UnicodeDecodeError:
             raise Exception(RDATA["UDE"])
         except FileNotFoundError:
@@ -78,7 +78,7 @@ class Fundb:
         >>> mdb.free_write("data")
         """
         with open(self.db_name+self.exten, "w") as a:
-            enc_data = encrypt(benc(str(data)), self.passwd, self.rotate, self.layer, self.rrotate)
+            enc_data = encrypt(str(data), self.passwd, self.rotate)
             a.write(enc_data)
             a.close()
             if(verbose):
@@ -93,7 +93,7 @@ class Fundb:
         """
         try:
             with open(self.db_name+self.exten, "r") as a:
-                data = decrypt(a.read(), self.passwd, self.rotate, self.layer, self.rrotate)
+                data = decrypt(a.read(), self.passwd, self.rotate)
                 a.close()
                 return bdec(data)
         except UnicodeDecodeError:
